import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import ReactDOM from 'react-dom';
import { csv } from 'd3';
import { message } from './message';

const csvUrl =
  'https://gist.githubusercontent.com/YaminiSreeram/6872ecff1ca4dbf958988415ef97641d/raw/00a30177b339dcbae928ac68d41820aee9a5247e/Amazon%2520Series%2520Data.csv';

const messageStyle = {
  fontFamily: 'Didot, serif',
  padding: '20px',
  backgroundColor: '#C19A6B',
  border: '1px solid #ccc',
  textAlign: 'center',
  fontSize: '20px',
  width: '400px',
  height: '150px',
  margin: 'auto',
};

const svgStyle = {
  width: '150px',
  height: '150px',
  margin: 'auto', // Center horizontally
  display: 'block', // Center horizontally
};

const faceStyle = {
  fill: 'pink',
  stroke: 'black',
  strokeWidth: '3',
};

const eyeStyle = {
  fill: 'black',
};

const noseStyle = {
  fill: 'grey',
};

const mouthStyle = {
  fill: 'red',
  stroke: 'black',
  strokeWidth: '2',
};

const capStyle = {
  fill: '#C58917',
  stroke: 'black',
  strokeWidth: '2',
};

const earStyle = {
  fill: 'brown',
  stroke: 'black',
  strokeWidth: '2',
};

const App = () => {
  const [data, setData] = useState(null);

  useEffect(() => {
    csv(csvUrl).then(setData);
  }, []);

  return (
    <div>
      <h1 style={{ textAlign: 'center', color: 'Tomato' }}>
        CSV for Amazon Series Data
      </h1>
      <pre style={messageStyle}>
        {data ? (
          <>
            <p>Amazon Series Data :</p>
            {message(data)}
          </>
        ) : (
          <span style={{ color: 'blue' }}>Loading...</span>
        )}
      </pre>
      {data && (
        <svg
          xmlns="http://www.w3.org/2000/svg"
          style={svgStyle}
        >
          <circle
            cx="75"
            cy="75"
            r="60"
            style={faceStyle}
          />
          <circle cx="45" cy="55" r="5" style={eyeStyle} />
          <circle cx="105" cy="55" r="5" style={eyeStyle} />
          <polygon
            points="75,60 70,70 80,70"
            style={noseStyle}
          />
          <path
            d="M 70 85 Q 75 90 80 85"
            style={mouthStyle}
          />

          {/* Cap as a polygon */}
          <rect
            x="25"
            y="5"
            width="100"
            height="20"
            style={capStyle}
          />
          {/* Ears */}
          <rect
            x="5"
            y="60"
            width="10"
            height="20"
            style={earStyle}
          />
          <rect
            x="135"
            y="60"
            width="10"
            height="20"
            style={earStyle}
          />
        </svg>
      )}
    </div>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
